@@ -3,7 +3,6 @@
 
 mod backend;
 mod cli;
-mod config;
 mod docker;
 mod store;
 mod util;
@@ -18,7 +17,7 @@ use cli::App;
 use docker::StoreRuntime;
 use std::io;
 
-use crate::config::{Backend, ConfigMap};
+use crate::cli::{Backend, BackendMap};
 
 #[tokio::main]
 async fn main() {
@@ -38,10 +37,10 @@ async fn main() {
 async fn try_main() -> Result<()> {
     let docker = Docker::connect_with_local_defaults()?;
     match App::parse() {
-        App::Init { config } => {
-            let config_map: ConfigMap = config.try_into()?;
-            for (name, backend) in config_map.into_iter() {
-                info!("init {name}...");
+        App::Init { backends } => {
+            let backends: BackendMap = backends.try_into()?;
+            for (name, backend) in backends.into_iter() {
+                info!("🎮 Initializing playground '{name}' ...");
                 match backend {
                     Backend::Postgres { port, user, password, database, .. } => {
                         docker.init(&Postgres { port, user, password, database }).await?;
@@ -54,11 +53,12 @@ async fn try_main() -> Result<()> {
                     }
                 }
             }
+            info!("✨ All playgrounds initialized successfully!");
         }
-        App::Stop { config } => {
-            let config_map: ConfigMap = config.try_into()?;
-            for (name, backend) in config_map.into_iter() {
-                info!("stop {name}...");
+        App::Stop { backends } => {
+            let backends: BackendMap = backends.try_into()?;
+            for (name, backend) in backends.into_iter() {
+                info!("🔌 Stopping playground '{name}' ...");
                 match backend {
                     Backend::Postgres { port, user, password, database, .. } => {
                         docker.stop(&Postgres { port, user, password, database }).await?;
@@ -71,6 +71,7 @@ async fn try_main() -> Result<()> {
                     }
                 }
             }
+            info!("🛑 All playgrounds stopped");
         }
         App::Completion { shell } => {
             let app = &mut App::into_app();
